pub enum CodeRequirementMatchExpression<'a> {
Show 15 variants
Exists,
Equal(CodeRequirementValue<'a>),
Contains(CodeRequirementValue<'a>),
BeginsWith(CodeRequirementValue<'a>),
EndsWith(CodeRequirementValue<'a>),
LessThan(CodeRequirementValue<'a>),
GreaterThan(CodeRequirementValue<'a>),
LessThanEqual(CodeRequirementValue<'a>),
GreaterThanEqual(CodeRequirementValue<'a>),
On(DateTime<Utc>),
Before(DateTime<Utc>),
After(DateTime<Utc>),
OnOrBefore(DateTime<Utc>),
OnOrAfter(DateTime<Utc>),
Absent,
}Expand description
An instance of a match expression in a CodeRequirementExpression.
Variants
Exists
Entity exists.
exists
No payload.
Equal(CodeRequirementValue<'a>)
Equality.
= <value>
4 bytes length, raw data.
Contains(CodeRequirementValue<'a>)
Contains.
~ <value>
4 bytes length, raw data.
BeginsWith(CodeRequirementValue<'a>)
Begins with.
= <value>*
4 bytes length, raw data.
EndsWith(CodeRequirementValue<'a>)
Ends with.
= *<value>
4 bytes length, raw data.
LessThan(CodeRequirementValue<'a>)
Less than.
< <value>
4 bytes length, raw data.
GreaterThan(CodeRequirementValue<'a>)
Greater than.
> <value>
LessThanEqual(CodeRequirementValue<'a>)
Less than or equal to.
<= <value>
4 bytes length, raw data.
GreaterThanEqual(CodeRequirementValue<'a>)
Greater than or equal to.
>= <value>
4 bytes length, raw data.
On(DateTime<Utc>)
Timestamp value equivalent.
= timestamp "<timestamp>"
Before(DateTime<Utc>)
Timestamp value before.
< timestamp "<timestamp>"
After(DateTime<Utc>)
Timestamp value after.
> timestamp "<timestamp>"
OnOrBefore(DateTime<Utc>)
Timestamp value equivalent or before.
<= timestamp "<timestamp>"
OnOrAfter(DateTime<Utc>)
Timestamp value equivalent or after.
>= timestamp "<timestamp>"
Absent
Value is absent.
<empty>
No payload.
Implementations
Sourceimpl<'a> CodeRequirementMatchExpression<'a>
impl<'a> CodeRequirementMatchExpression<'a>
Sourcepub fn from_bytes(
data: &'a [u8],
) -> Result<(Self, &'a [u8]), AppleCodesignError>
pub fn from_bytes( data: &'a [u8], ) -> Result<(Self, &'a [u8]), AppleCodesignError>
Parse a match expression from bytes.
The slice should begin with the match type u32.