pub enum DigestType {
None,
Sha1,
Sha256,
Sha256Truncated,
Sha384,
Sha512,
Unknown(u8),
}Expand description
Represents a digest type encountered in code signature data structures.
Variants
Implementations
Sourceimpl DigestType
impl DigestType
Sourcepub fn hash_len(&self) -> Result<usize, AppleCodesignError>
pub fn hash_len(&self) -> Result<usize, AppleCodesignError>
Obtain the size of hashes for this hash type.
Sourcepub fn as_hasher(&self) -> Result<Context, AppleCodesignError>
pub fn as_hasher(&self) -> Result<Context, AppleCodesignError>
Obtain a hasher for this digest type.
Sourcepub fn digest_data(&self, data: &[u8]) -> Result<Vec<u8>, AppleCodesignError>
pub fn digest_data(&self, data: &[u8]) -> Result<Vec<u8>, AppleCodesignError>
Digest data given the configured hasher.