pub struct DmgReader { /* private fields */ }Expand description
An entity for reading DMG files.
It only implements enough to create code signatures over the DMG.
Implementations
Sourceimpl DmgReader
impl DmgReader
Sourcepub fn new<R: Read + Seek>(reader: &mut R) -> Result<Self, AppleCodesignError>
pub fn new<R: Read + Seek>(reader: &mut R) -> Result<Self, AppleCodesignError>
Construct a new instance from a reader.
Sourcepub fn koly(&self) -> &KolyTrailer
pub fn koly(&self) -> &KolyTrailer
Obtain the main data structure describing this DMG.
Sourcepub fn embedded_signature(
&self,
) -> Result<Option<EmbeddedSignature<'_>>, AppleCodesignError>
pub fn embedded_signature( &self, ) -> Result<Option<EmbeddedSignature<'_>>, AppleCodesignError>
Obtain the embedded code signature superblob.
Sourcepub fn digest_content_with<R: Read + Seek>(
&self,
digest: DigestType,
reader: &mut R,
) -> Result<Digest<'static>, AppleCodesignError>
pub fn digest_content_with<R: Read + Seek>( &self, digest: DigestType, reader: &mut R, ) -> Result<Digest<'static>, AppleCodesignError>
Digest the content of the DMG up to the code signature or KolyTrailer.
This digest is used as the code digest in the code directory.