pub struct DmgSigner {}Expand description
Entity for signing DMG files.
Implementations
Sourceimpl DmgSigner
impl DmgSigner
Sourcepub fn sign_file(
&self,
settings: &SigningSettings<'_>,
fh: &mut File,
) -> Result<(), AppleCodesignError>
pub fn sign_file( &self, settings: &SigningSettings<'_>, fh: &mut File, ) -> Result<(), AppleCodesignError>
Sign a DMG.
Parameters controlling the signing operation are specified by settings.
file is a readable and writable file. The DMG signature will be written
into the source file.
Sourcepub fn staple_file(
&self,
fh: &mut File,
ticket_data: Vec<u8>,
) -> Result<(), AppleCodesignError>
pub fn staple_file( &self, fh: &mut File, ticket_data: Vec<u8>, ) -> Result<(), AppleCodesignError>
Staple a notarization ticket to a DMG.
Sourcepub fn create_superblob<F: Read + Write + Seek>(
&self,
settings: &SigningSettings<'_>,
fh: &mut F,
) -> Result<Vec<u8>, AppleCodesignError>
pub fn create_superblob<F: Read + Write + Seek>( &self, settings: &SigningSettings<'_>, fh: &mut F, ) -> Result<Vec<u8>, AppleCodesignError>
Create the embedded signature superblob content.
Sourcepub fn create_code_directory<F: Read + Write + Seek>(
&self,
settings: &SigningSettings<'_>,
fh: &mut F,
) -> Result<CodeDirectoryBlob<'static>, AppleCodesignError>
pub fn create_code_directory<F: Read + Write + Seek>( &self, settings: &SigningSettings<'_>, fh: &mut F, ) -> Result<CodeDirectoryBlob<'static>, AppleCodesignError>
Create the code directory data structure that is part of the embedded signature.
This won’t be the final data structure state that is serialized, as it may be amended to in other functions.
Sourcepub fn create_special_blobs(
&self,
) -> Result<Vec<(CodeSigningSlot, BlobData<'_>)>, AppleCodesignError>
pub fn create_special_blobs( &self, ) -> Result<Vec<(CodeSigningSlot, BlobData<'_>)>, AppleCodesignError>
Create special blobs that are added to the superblob.