pub struct EncodedEnvironmentConstraints {
pub ccat: u64,
pub comp: u64,
pub requirements: Dictionary,
pub vers: u64,
}Expand description
Represents the DER encoded form of environment constraints.
Instances can be converted into a Value using .into().
Fields
ccat: u64We’re not sure what this is.
Value always appears to be 0.
comp: u64We’re not sure what this is.
Value always appears to be 1.
We hypothesize it might be a compatibility version number.
requirements: DictionaryThe user-provided constraints, as a mapping.
vers: u64We’re not sure what this is.
Value always appears to be 1.
We hypothesize it is a version number.
Implementations
Sourceimpl EncodedEnvironmentConstraints
impl EncodedEnvironmentConstraints
Sourcepub fn from_der(data: impl AsRef<[u8]>) -> Result<Self>
pub fn from_der(data: impl AsRef<[u8]>) -> Result<Self>
Attempt to decode an instance from DER.
Sourcepub fn from_requirements_plist(value: Value) -> Result<Self>
pub fn from_requirements_plist(value: Value) -> Result<Self>
Obtain an instance from a requirements plist.
Sourcepub fn from_requirements_plist_file(path: impl AsRef<Path>) -> Result<Self>
pub fn from_requirements_plist_file(path: impl AsRef<Path>) -> Result<Self>
Attempt to construct an instance by reading requirements plist data from a file.
Source file can be XML or binary encoding.
Sourcepub fn der_encode(&self) -> Result<Vec<u8>>
pub fn der_encode(&self) -> Result<Vec<u8>>
Encode the instance to DER.
Sourcepub fn requirements_plist(&self) -> Value
pub fn requirements_plist(&self) -> Value
Obtain just the requirements as a plist Value.