pub struct BundleSigningContext<'a, 'key> {
pub settings: &'a SigningSettings<'key>,
pub dest_dir: PathBuf,
pub previously_installed_paths: BTreeSet<PathBuf>,
pub installed_paths: BTreeSet<PathBuf>,
}Expand description
Holds state and helper methods to facilitate signing a bundle.
Fields
settings: &'a SigningSettings<'key>Settings for this bundle.
dest_dir: PathBufWhere the bundle is getting installed to.
previously_installed_paths: BTreeSet<PathBuf>Bundle relative paths of files that have already been installed.
The already-present destination file content should be used for sealing.
installed_paths: BTreeSet<PathBuf>Bundle relative paths of files that are installed by this signing operation.
Implementations
Sourceimpl<'a, 'key> BundleSigningContext<'a, 'key>
impl<'a, 'key> BundleSigningContext<'a, 'key>
Sourcepub fn install_file(
&mut self,
source_path: &Path,
bundle_rel_path: &Path,
) -> Result<PathBuf, AppleCodesignError>
pub fn install_file( &mut self, source_path: &Path, bundle_rel_path: &Path, ) -> Result<PathBuf, AppleCodesignError>
Install a file (regular or symlink) in the destination directory.
Sourcepub fn sign_and_install_macho(
&mut self,
source_path: &Path,
bundle_rel_path: &Path,
) -> Result<(PathBuf, SignedMachOInfo), AppleCodesignError>
pub fn sign_and_install_macho( &mut self, source_path: &Path, bundle_rel_path: &Path, ) -> Result<(PathBuf, SignedMachOInfo), AppleCodesignError>
Sign a Mach-O file and ensure its new content is installed.
Returns Mach-O metadata which can be recorded in a CodeResources file.