pub struct CodeResourcesRule {
pub pattern: String,
pub exclude: bool,
pub nested: bool,
pub omit: bool,
pub optional: bool,
pub weight: Option<u32>,
/* private fields */
}Expand description
Represents an abstract rule in a CodeResources XML plist.
This type represents both <rules> and <rules2> entries. It contains a
superset of all fields for these entries.
Fields
pattern: StringThe rule pattern.
The <key> in the <rules> or <rules2> dict.
exclude: boolMatched paths are excluded from processing completely.
If any rule with this flag matches a path, the path is excluded.
nested: boolThe matched path is a signable entity.
The path should be signed before sealing. And its seal may be stored specially.
omit: boolWhether to omit the path from sealing.
Paths matching this rule can exist in a bundle. But their content
isn’t captured in the CodeResources file.
optional: boolUnknown. Best guess is whether the file’s presence is optional.
weight: Option<u32>Weighting to apply to the rule.
Implementations
Sourceimpl CodeResourcesRule
impl CodeResourcesRule